@@ -16,16 +16,18 @@
 #' @import dplyr
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET content set_config config
-#' @importFrom data.table rbindlist
 #' @family lookup functions
 #' @seealso \code{\link{area_types}} for area type  and their parent mappings,
 #'   \code{\link{indicators}} for indicator lookups,
 #'   \code{\link{indicator_metadata}} for indicator metadata and
-#'   \code{\link{deprivation_decile}} for deprivation decile lookups
+#'   \code{\link{deprivation_decile}} for deprivation decile lookups and
+#'   \code{\link{category_types}} for category lookups and
+#'   \code{\link{indicator_areatypes}} for indicators by area types lookups and
+#'   \code{\link{indicators_unique}} for unique indicatorids and their names
 #' @export
 
-profiles <- function(ProfileID = NULL, ProfileName = NULL) {
-        path <- "https://fingertips.phe.org.uk/api/"
+profiles <- function(ProfileID = NULL, ProfileName = NULL, path) {
+        if (missing(path)) path <- "https://fingertips.phe.org.uk/api/"
         set_config(config(ssl_verifypeer = 0L))
         profiles <- paste0(path,"profiles") %>%
                 GET %>%
@@ -35,11 +37,9 @@ profiles <- function(ProfileID = NULL, ProfileName = NULL) {
 
         profiles <- lapply(profiles$GroupIds, data.frame)
         names(profiles) <- idname$Id
-        profiles <- rbindlist(profiles,
-                              use.names = TRUE,
-                              fill = TRUE,
-                              idcol = "profiles") %>%
-                mutate(profiles = as.numeric(profiles)) %>%
+        profiles <- bind_rows(profiles,
+                              .id = "profiles") %>%
+                mutate(profiles = as.integer(profiles)) %>%
                 left_join(idname, by = c("profiles" = "Id"))
         names(profiles) <- c("ID", "groupid", "Name")
         profiles <- profiles[, c("ID", "Name", "groupid")]
@@ -54,17 +54,26 @@ profiles <- function(ProfileID = NULL, ProfileName = NULL) {
                         stop("Profile names are not in the list of profile names. Re-run the function without any inputs to see all possible names.")
                 }
         }
-        groupDescriptions <- data.frame()
-        for (i in unique(profiles$ID)){
-                query <- paste0(path,"group_metadata?group_ids=",
-                                paste(profiles$groupid[profiles$ID == i],
-                                      collapse = "%2C"))
-                groupDescriptions <- rbind(query %>% GET %>% content("text") %>% fromJSON(), groupDescriptions)
-        }
+        i <- profiles %>%
+                group_by(ID) %>%
+                summarise(combined = paste(groupid, collapse = "%2C"))
+        groupDescriptions <- data.frame(ID = unique(profiles$ID),
+                                        path = paste0(path,"group_metadata?group_ids=")) %>%
+                left_join(i, by = c("ID" = "ID")) %>%
+                mutate(dataurl = paste0(path, combined)) %>%
+                               pull %>%
+                lapply(function(dataurl) {
+                        dataurl %>%
+                                GET %>%
+                                content("text") %>%
+                                fromJSON
+                }) %>%
+                bind_rows
         groupDescriptions <- groupDescriptions %>%
                 select(Id, Name)
         profiles <- rename(profiles,ProfileID = ID,ProfileName = Name, DomainID = groupid) %>%
                 left_join(groupDescriptions, by = c("DomainID" = "Id")) %>%
-                rename(DomainName = Name)
+                rename(DomainName = Name) %>%
+                as_tibble
         return(profiles)
 }
